@@ -3,16 +3,28 @@ from uv_secure.package_info.dependency_file_parser import (
     parse_pylock_toml_file,
     parse_requirements_txt_file,
     parse_uv_lock_file,
+    ParseResult,
+)
+from uv_secure.package_info.package_index_downloader import (
+    download_package_indexes,
+    PackageIndex,
+    ProjectState,
 )
 from uv_secure.package_info.package_info_downloader import (
     download_packages,
     PackageInfo,
+    Vulnerability,
 )
 
 
 __all__ = [
     "Dependency",
+    "PackageIndex",
     "PackageInfo",
+    "ParseResult",
+    "ProjectState",
+    "Vulnerability",
+    "download_package_indexes",
     "download_packages",
     "parse_pylock_toml_file",
     "parse_requirements_txt_file",
