@@ -4,6 +4,7 @@ import sys
 import typer
 
 from uv_secure import __version__
+from uv_secure.configuration import OutputFormat
 from uv_secure.dependency_checker import check_lock_files, RunStatus
 
 
@@ -64,6 +65,24 @@ _disable_cache_option = typer.Option(
     help="Flag whether to disable caching for vulnerability http requests",
 )
 
+_forbid_archived_option = typer.Option(
+    None,
+    "--forbid-archived",
+    help="Flag whether disallow archived package versions from being dependencies",
+)
+
+_forbid_deprecated_option = typer.Option(
+    None,
+    "--forbid-deprecated",
+    help="Flag whether disallow deprecated package versions from being dependencies",
+)
+
+_forbid_quarantined_option = typer.Option(
+    None,
+    "--forbid-quarantined",
+    help="Flag whether disallow quarantined package versions from being dependencies",
+)
+
 _forbid_yanked_option = typer.Option(
     None,
     "--forbid-yanked",
@@ -106,7 +125,7 @@ _version_option = typer.Option(
     "--version",
     callback=_version_callback,
     is_eager=True,
-    help="Show the application's version",
+    help="Show the application version",
 )
 
 
@@ -122,6 +141,15 @@ _ignore_pkg_options = typer.Option(
 )
 
 
+_format_option = typer.Option(
+    None,
+    "--format",
+    help=(
+        "Output format: 'columns' for table output (default) or 'json' for JSON output"
+    ),
+)
+
+
 @app.command()
 def main(
     file_paths: list[Path] | None = _file_path_args,
@@ -130,6 +158,9 @@ def main(
     cache_path: Path = _cache_path_option,
     cache_ttl_seconds: float = _cache_ttl_seconds_option,
     disable_cache: bool = _disable_cache_option,
+    forbid_archived: bool | None = _forbid_archived_option,
+    forbid_deprecated: bool | None = _forbid_deprecated_option,
+    forbid_quarantined: bool | None = _forbid_quarantined_option,
     forbid_yanked: bool | None = _forbid_yanked_option,
     max_package_age: int | None = _max_package_age_option,
     ignore_vulns: str | None = _ignore_vulns_option,
@@ -140,18 +171,18 @@ def main(
     | None = _check_direct_dependency_maintenance_issues_only_option,
     config_path: Path | None = _config_option,
     version: bool = _version_option,
+    format_type: OutputFormat | None = _format_option,
 ) -> None:
     """Parse uv.lock, pylock.toml, and requirements.txt files.
 
     Check vulnerabilities and display summary.
     """
-
     # Use uvloop or winloop if present
     try:
         if sys.platform in {"win32", "cygwin", "cli"}:
-            from winloop import run
+            from winloop import run  # type: ignore[import-not-found, unused-ignore]
         else:
-            from uvloop import run  # type: ignore[no-redef, unused-ignore]
+            from uvloop import run  # type: ignore[no-redef, import-not-found, unused-ignore]  # noqa: I001
     except ImportError:
         from asyncio import run  # type: ignore[assignment, unused-ignore]
 
@@ -163,6 +194,9 @@ def main(
             cache_path,
             cache_ttl_seconds,
             disable_cache,
+            forbid_archived,
+            forbid_deprecated,
+            forbid_quarantined,
             forbid_yanked,
             max_package_age,
             ignore_vulns,
@@ -170,6 +204,7 @@ def main(
             check_direct_dependency_vulnerabilities_only,
             check_direct_dependency_maintenance_issues_only,
             config_path,
+            format_type.value if format_type is not None else None,
         )
     )
     if run_status == RunStatus.MAINTENANCE_ISSUES_FOUND:
